@@ -1071,7 +1071,7 @@ sub log_response {
         $has_errors = 1;
 
         $errors = $c->stash->{is_api_error_response}
-                    ? join ', ', splice @{$c->error}, 1
+                    ? join ', ', (splice @{$c->error}, 1) // ()
                     : join ', ', @{$c->error};
 
         # unhandled error message, should return 500 instead of 200
@@ -2204,7 +2204,7 @@ sub check_wildcard_search {
 
 sub check_deadlock {
     my ($self, $c, $error) = @_;
-    my $max_attempts = 2;
+    my $max_attempts = 5;
 
     return 0 unless $error;
 
@@ -2224,6 +2224,7 @@ sub check_deadlock {
         log  => ($lockwait_retry and $lockwait_err or $deadlock_err),
     );
     $c->stash->{deadlock_retry_attempt} = $attempt+1;
+    sleep 1;
     return 1;
 }
 
